// Copyright (C) 2017 The Android Open Source Project
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.googlesource.gerrit.plugins.oauth;

import com.github.scribejava.core.builder.api.DefaultApi20;
import com.github.scribejava.core.oauth2.bearersignature.BearerSignature;
import com.github.scribejava.core.oauth2.bearersignature.BearerSignatureURIQueryParameter;
import com.github.scribejava.core.oauth2.clientauthentication.ClientAuthentication;
import com.github.scribejava.core.oauth2.clientauthentication.RequestBodyAuthenticationScheme;

public class KeycloakApi extends DefaultApi20 {

  private static final String AUTHORIZE_URL = "%s/auth/realms/%s/protocol/openid-connect/auth";

  private final String rootUrl;
  private final String realm;

  public KeycloakApi(String rootUrl, String realm) {
    this.rootUrl = rootUrl;
    this.realm = realm;
  }

  @Override
  public String getAuthorizationBaseUrl() {
    return String.format(AUTHORIZE_URL, rootUrl, realm);
  }

  @Override
  public String getAccessTokenEndpoint() {
    return String.format("%s/auth/realms/%s/protocol/openid-connect/token", rootUrl, realm);
  }

  @Override
  public BearerSignature getBearerSignature() {
    return BearerSignatureURIQueryParameter.instance();
  }

  @Override
  public ClientAuthentication getClientAuthentication() {
    return RequestBodyAuthenticationScheme.instance();
  }
}
